@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-09-03 10:47:19
+@LastEditTime: 2021-09-07 17:01:51
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -542,10 +542,10 @@ class GivePropHandler(SevenBaseHandler):
 
         now_date = self.get_now_datetime()
         if act_dict['start_date'] != "":
-            if TimeHelper.format_time_to_datetime(now_date) < TimeHelper.format_time_to_datetime(act_dict['start_date']):
+            if TimeHelper.format_time_to_datetime(str(now_date)) < TimeHelper.format_time_to_datetime(str(act_dict['start_date'])):
                 return self.reponse_json_error("NoAct", "活动将在" + str(act_dict['start_date']) + "开启")
         if act_dict['end_date'] != "":
-            if TimeHelper.format_time_to_datetime(now_date) > TimeHelper.format_time_to_datetime(act_dict['end_date']):
+            if TimeHelper.format_time_to_datetime(str(now_date)) > TimeHelper.format_time_to_datetime(str(act_dict['end_date'])):
                 return self.reponse_json_error("NoAct", "活动已结束")
         user_info = user_info_model.get_entity("open_id=%s and act_id=%s", params=[open_id, act_id])
         if not user_info or user_info.act_id != act_id:
@@ -665,10 +665,10 @@ class GetPropGiveHandler(SevenBaseHandler):
             return self.reponse_json_error("NoAct", "对不起，活动不存在")
         now_date = self.get_now_datetime()
         if act_dict['start_date'] != "":
-            if TimeHelper.format_time_to_datetime(now_date) < TimeHelper.format_time_to_datetime(act_dict['start_date']):
+            if TimeHelper.format_time_to_datetime(str(now_date)) < TimeHelper.format_time_to_datetime(str(act_dict['start_date'])):
                 return self.reponse_json_error("NoAct", "活动将在" + str(act_dict['start_date']) + "开启")
         if act_dict['end_date'] != "":
-            if TimeHelper.format_time_to_datetime(now_date) > TimeHelper.format_time_to_datetime(act_dict['end_date']):
+            if TimeHelper.format_time_to_datetime(str(now_date)) > TimeHelper.format_time_to_datetime(str(act_dict['end_date'])):
                 return self.reponse_json_error("NoAct", "活动已结束")
         user_info = user_info_model.get_entity("open_id=%s and act_id=%s", params=[open_id, act_id])
         if not user_info or user_info.act_id != act_id:
@@ -695,10 +695,13 @@ class GetPropGiveHandler(SevenBaseHandler):
             return self.reponse_json_error("Error", "对不起，用户不存在")
         if prop_give.prop_type == 3:
             history_value = user_detail.tips_card_count
+            update_sql = "tips_card_count=tips_card_count+1"
         elif prop_give.prop_type == 4:
             history_value = user_detail.redraw_card_count
+            update_sql = "redraw_card_count=redraw_card_count+1"
         else:
             history_value = user_detail.perspective_card_count
+            update_sql = "perspective_card_count=perspective_card_count+1"
         prop_log = PropLog()
         prop_log.app_id = app_id
         prop_log.act_id = act_id
